@@ -13,15 +13,15 @@ class ImJoyPlugin:
 
     async def setup(self):
         """Set up the plugin."""
-        token = await api.generateToken({})
-        assert token["success"]
-        print(f'Generated token: {token["result"]}')
+        token = await api.generateToken()
+        assert token["token"]
+        print(f'Generated token: {token["token"]}')
 
-        await api.registerService(
+        await api.register_service(
             {"name": "echo service", "echo": lambda x: print("echo: " + str(x))}
         )
-        service = await api.getService("echo service")
-        await service.echo("a message")
+        service = await api.get_services({"name": "echo service"})
+        await service[0].echo("a message")
         await api.log("initialized")
 
     async def run(self, ctx):
